# Space Imaging Simulator for Proximity Operations (SISPO)

[![sispo](https://img.shields.io/badge/powered%20by-sispo-orange?style=flat)](https://github.com/YgabrielsY/sispo)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3661054.svg)](https://doi.org/10.5281/zenodo.3661054)

Currently, a problem exists with the `mathutils` import in the `sim.py`. An import of `bpy` must be done before running sispo.

## Documentation

[![Documentation Status](https://readthedocs.org/projects/sispo/badge/?version=latest)](https://sispo.readthedocs.io/en/latest/?badge=latest)

Currently, the most extensive documentation on the project can be found in the `doc` folder. It contains the master thesis that was the starting point of this repository. The thesis is written in Latex and might need to be compiled.

Another kind of documentation is started using Read the Docs. It can be found by following the badge.

If you are using this package in a code project, please acknowledge by adding our badge to your readme file by copying:

`[![sispo](https://img.shields.io/badge/powered%20by-sispo-orange?style=flat)](https://github.com/YgabrielsY/sispo)`

There is another repository linked to sispo which uses Docker to simplify the installation. Can be found here [sispo_docker](https://github.com/SISPO-developers/sispo_docker)

## Acknowledgements
Acknowledgements to packages used

[![astropy](http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat)](http://www.astropy.org/)
